package
Version:
v0.0.0-...-5e9046f
Opens a new window with list of versions in this module.
Published: Feb 14, 2022
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
const (
BigCharWidth = 3
BigCharHeight = 5
)
func (p Point) ProgressBar(length, cur, total int)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.